********
Overview
********

.. include:: ../../README.rst

.. note::

    On version 0.20 there was an inversion of roles and instead of depending on
    `PySeabird package <http://seabird.castelao.net>`_, now CoTeDe is an
    independent package that can be installed as an extra-requirement of
    `PySeabird package <http://seabird.castelao.net>`_. The functionalities
    to quality control CTD and TSG are now in the package PySeabird. This
    allowed CoTeDe to focus on QC and better generalize for other platforms
    and instruments.
